/***************************************************************************
                          About.h  -  description
                             -------------------
    begin                : Sun Oct 3 1999
    copyright            : (C) 1997-2000 by Peter Putzer
    email                : putzer@kde.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2.                              *
 *                                                                         *
 ***************************************************************************/

/*
 * About-Dialog for ksysv
 */

#ifndef KSV_ABOUT_H
#define KSV_ABOUT_H

#include <kdialogbase.h>

class QString;

class AboutDlg : public KDialogBase
{
  Q_OBJECT

public:
  static AboutDlg* self ();
  virtual ~AboutDlg();

private slots:
  void callMailer (const QString& url);
  void openHomePage (const QString& url);

private:
  AboutDlg (QWidget* parent);

  QString mAppName;
};

#endif


